[llvm] r220901 - [OCaml] Test code emission in Llvm_target.

Peter Zotov whitequark at whitequark.org
Thu Oct 30 01:30:01 PDT 2014


Author: whitequark
Date: Thu Oct 30 03:30:01 2014
New Revision: 220901

URL: http://llvm.org/viewvc/llvm-project?rev=220901&view=rev
Log:
[OCaml] Test code emission in Llvm_target.

Prior to this commit, the Llvm_target tests (ab)used
the Llvm_executionengine as a mechanism to initialize at least some
target. This needlessly restricted tests to builds which can emit
code for their host architecture.

Modified:
    llvm/trunk/test/Bindings/Ocaml/target.ml

Modified: llvm/trunk/test/Bindings/Ocaml/target.ml
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/Bindings/Ocaml/target.ml?rev=220901&r1=220900&r2=220901&view=diff
==============================================================================
--- llvm/trunk/test/Bindings/Ocaml/target.ml (original)
+++ llvm/trunk/test/Bindings/Ocaml/target.ml Thu Oct 30 03:30:01 2014
@@ -1,7 +1,6 @@
 (* RUN: cp %s %T/target.ml
  * RUN: %ocamlcomp -g -warn-error A -package llvm.target -package llvm.executionengine -linkpkg %T/target.ml -o %t
  * RUN: %t %t.bc
- * REQUIRES: native, object-emission
  * XFAIL: vg_leak
  *)
 
@@ -12,7 +11,7 @@
 open Llvm
 open Llvm_target
 
-let _ = Llvm_executionengine.initialize_native_target ()
+let () = Llvm_all_backends.initialize ()
 
 let context = global_context ()
 let i32_type = Llvm.i32_type context
@@ -112,5 +111,5 @@ let _ =
   test_target_data ();
   test_target ();
   test_target_machine ();
-  (* test_code_emission (); *) (* broken without AsmParser support *)
+  test_code_emission ();
   dispose_module m
@@ -1,7 +1,6 @@
 (* RUN: cp %s %T/target.ml
- * RUN: %ocamlcomp -g -warn-error A -package llvm.target -package llvm.executionengine -linkpkg %T/target.ml -o %t
+ * RUN: %ocamlcomp -g -warn-error A -package llvm.target -package llvm.all_backends -linkpkg %T/target.ml -o %t
  * RUN: %t %t.bc





More information about the llvm-commits mailing list